@@ -537,14 +537,12 @@ bool Agenda::eventFilter(QObject *object, QEvent *event)
         return QWidget::eventFilter(object, event);
 
 #ifndef QT_NO_DRAGANDDROP
-#ifndef KORG_NODND
     case QEvent::DragEnter:
     case QEvent::DragMove:
     case QEvent::DragLeave:
     case QEvent::Drop:
 //  case QEvent::DragResponse:
         return eventFilter_drag(object, static_cast<QDropEvent *>(event));
-#endif
 #endif
 
     default:
@@ -1678,7 +1676,7 @@ QVector<int> Agenda::minContentsY() const
 {
     QVector<int> minArray;
     minArray.fill(timeToY(QTime(23, 59)), d->mSelectedDates.count());
-    foreach (AgendaItem::QPtr item, d->mItems) {
+    for (AgendaItem::QPtr item : qAsConst(d->mItems)) {
         if (item) {
             int ymin = item->cellYTop();
             int index = item->cellXLeft();
@@ -1697,7 +1695,7 @@ QVector<int> Agenda::maxContentsY() const
 {
     QVector<int> maxArray;
     maxArray.fill(timeToY(QTime(0, 0)), d->mSelectedDates.count());
-    foreach (AgendaItem::QPtr item, d->mItems) {
+    for (AgendaItem::QPtr item : qAsConst(d->mItems)) {
         if (item) {
             int ymax = item->cellYBottom();
 
@@ -2177,7 +2175,7 @@ void Agenda::selectItem(const AgendaItem::QPtr &item)
     Q_ASSERT(d->mSelectedItem->incidence());
     d->mSelectedId = d->mSelectedItem->incidence()->uid();
 
-    foreach (AgendaItem::QPtr item, d->mItems) {
+    for (AgendaItem::QPtr item : qAsConst(d->mItems)) {
         if (item && item->incidence()->uid() == d->mSelectedId) {
             item->select();
         }
@@ -2187,7 +2185,7 @@ void Agenda::selectItem(const AgendaItem::QPtr &item)
 
 void Agenda::selectIncidenceByUid(const QString &uid)
 {
-    foreach (AgendaItem::QPtr item, d->mItems) {
+    for (const AgendaItem::QPtr &item : qAsConst(d->mItems)) {
         if (item && item->incidence()->uid() == uid) {
             selectItem(item);
             break;
