@@ -317,7 +317,7 @@ void MonthGraphicsItem::paint(QPainter *p, const QStyleOptionGraphicsItem *, QWi
 
         // assume that all pixmaps have the same height
         int pixYPos = icons.isEmpty() ? 0 : (textRect.height() - icons.at(0).height()) / 2;
-        foreach (const QPixmap &icon, icons) {
+        for (const QPixmap &icon : qAsConst(icons)) {
             p->drawPixmap(curXPos, pixYPos, icon);
             curXPos += icon.width();
         }
