@@ -30,10 +30,10 @@
 #include <CalendarSupport/CategoryConfig>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/CategoryHierarchyReader>
-#include <Libkdepim/TagSelectionCombo>
+#include <LibkdepimAkonadi/TagSelectionCombo>
 
 #include <Libkdepim/KCheckComboBox>
-#include <Libkdepim/TagWidgets>
+#include <LibkdepimAkonadi/TagWidgets>
 
 #include <KCalCore/CalFilter>
 
@@ -291,7 +291,7 @@ void TodoDueDateDelegate::updateEditorGeometry(QWidget *editor,
 // ---------------------------------------------------------------
 
 TodoCategoriesDelegate::TodoCategoriesDelegate(QObject *parent)
-    : QStyledItemDelegate(parent), mCalendar(Q_NULLPTR)
+    : QStyledItemDelegate(parent), mCalendar(nullptr)
 {
 }
 
